@@ -36,7 +36,7 @@ use strict;
 use vars qw($VERSION $AUTOLOAD %stdCase);
 use Image::ExifTool qw(:DataAccess :Utils);
 
-$VERSION = '1.65';
+$VERSION = '1.68';
 
 sub ProcessPNG_tEXt($$$);
 sub ProcessPNG_iTXt($$$);
@@ -351,6 +351,27 @@ my %noLeapFrog = ( SAVE => 1, SEEK => 1, IHDR => 1, JHDR => 1, IEND => 1, MEND =
             TagTable => 'Image::ExifTool::PNG::CICodePoints',
         },
     },
+    cpIp => { # OLE information found in PNG Plus images written by Picture It!
+        Name => 'OLEInfo',
+        Condition => q{
+            # set FileType to "PNG Plus"
+            if ($$self{VALUE}{FileType} and $$self{VALUE}{FileType} eq "PNG") {
+                $$self{VALUE}{FileType} = 'PNG Plus';
+            }
+            return 1;
+        },
+        SubDirectory => {
+            TagTable => 'Image::ExifTool::FlashPix::Main',
+            ProcessProc => 'Image::ExifTool::FlashPix::ProcessFPX',
+        },
+    },
+    meTa => { # XML in UTF-16 BOM format written by Picture It!
+        SubDirectory => {
+            TagTable => 'Image::ExifTool::XMP::XML',
+            IgnoreProp => { meta => 1 }, # ignore 'meta' container
+        },
+    },
+    # mkBF,mkTS,mkBS,mkBT ? - written by Adobe FireWorks
 );
 
 # PNG IHDR chunk
@@ -621,8 +642,8 @@ my %unreg = ( Notes => 'unregistered' );
     Label       => { %unreg },
     Make        => { %unreg, Groups => { 2 => 'Camera' } },
     Model       => { %unreg, Groups => { 2 => 'Camera' } },
-    # parameters      (written by Stable Diffusion)
-    # aesthetic_score (written by Stable Diffusion)
+    parameters  => { %unreg }, # (written by Stable Diffusion)
+    aesthetic_score => { Name => 'AestheticScore', %unreg }, # (written by Stable Diffusion)
    'create-date'=> {
         Name => 'CreateDate',
         Groups => { 2 => 'Time' },
@@ -970,6 +991,7 @@ sub FoundPNG($$$$;$$$$)
                     TagInfo  => $tagInfo,
                     ReadOnly => 1, # (used only by WriteXMP)
                     OutBuff  => $outBuff,
+                    IgnoreProp => $$subdir{IgnoreProp}, # (XML hack for meTa chunk)
                 );
                 # no need to re-decompress if already done
                 undef $processProc if $wasCompressed and $processProc and $processProc eq \&ProcessPNG_Compressed;
@@ -1378,7 +1400,7 @@ sub ProcessPNG($$)
     my $fastScan = $et->Options('FastScan');
     my $hash = $$et{ImageDataHash};
     my ($n, $sig, $err, $hbuf, $dbuf, $cbuf);
-    my ($wasHdr, $wasEnd, $wasDat, $doTxt, @txtOffset);
+    my ($wasHdr, $wasEnd, $wasDat, $doTxt, @txtOffset, $wasTrailer);
 
     # check to be sure this is a valid PNG/MNG/JNG image
     return 0 unless $raf->Read($sig,8) == 8 and $pngLookup{$sig};
@@ -1439,6 +1461,7 @@ sub ProcessPNG($$)
         if ($wasEnd) {
             last unless $n; # stop now if normal end of PNG
             $et->WarnOnce("Trailer data after $fileType $endChunk chunk", 1);
+            $wasTrailer = 1;
             last if $n < 8;
             $$et{SET_GROUP1} = 'Trailer';
         } elsif ($n != 8) {
@@ -1632,6 +1655,13 @@ sub ProcessPNG($$)
         }
     }
     delete $$et{SET_GROUP1};
+    # read Samsung trailer if it exists
+    if ($wasTrailer and not $outfile and $raf->Seek(-8, 2) and
+        $raf->Read($dbuf,8) and $dbuf =~ /\0\0(QDIOBS|SEFT)$/) # (have only seen SEFT type)
+    {
+        require Image::ExifTool::Samsung;
+        Image::ExifTool::Samsung::ProcessSamsung($et, { DirName => 'Samsung', RAF => $raf });
+    }
     return -1 if $outfile and ($err or not $wasEnd);
     return 1;   # this was a valid PNG/MNG/JNG image
 }
@@ -1656,7 +1686,7 @@ and JNG (JPEG Network Graphics) images.
 
 =head1 AUTHOR
 
-Copyright 2003-2023, Phil Harvey (philharvey66 at gmail.com)
+Copyright 2003-2024, Phil Harvey (philharvey66 at gmail.com)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
